# NOTE on SAT implementations.
# Upstream wants MathSat, which is nonfree and closed source.  We can do
# without the solving capability, or we can look for an alternative:
# - glpk: either solves for floating point numbers or integers, but we need to
#   solve for rational solutions.  Looks infeasible.
# - CVC4: has a rational solver, unknown whether it accepts constraints
# - linbox: has a rational solver, unknown whether it accepts constraints

%define basen     cocoa
%define major     0
%define libname   %mklibname %{basen} %{major}
%define develname %mklibname %{basen} -d

Name:           cocoalib
Version:        0.99850
Group:          System/Libraries
Release:        %mkrel 5
Summary:        C++ library for computations in commutative algebra

License:        GPLv3+
URL:            https://cocoa.dima.unige.it/cocoa/
Source0:        https://cocoa.dima.unige.it/cocoa/%{name}/tgz/CoCoALib-%{version}.tgz
# Build a shared library instead of a static library
Patch0:         %{name}-shared.patch
# Fix error handling in Qsolve
Patch1:         %{name}-ffelem.patch
# Fix out of bounds vector accesses
Patch2:         %{name}-vec.patch
# Avoid using a variable uninitialized
Patch3:         %{name}-uninit.patch
# CVC5 patch to enable tracing
Patch4:         %{name}-cvc5.patch 

BuildRequires:  boost-devel
BuildRequires:  cddlib-devel
BuildRequires:  frobby-devel
BuildRequires:  gmp-devel
BuildRequires:  gsl-devel
BuildRequires:  gfan-devel
BuildRequires:  blas-devel
BuildRequires:  lapack-devel
BuildRequires:  readline-devel
BuildRequires:  texlive-texmf
BuildRequires:  txt2tags

%description
The CoCoA C++ library offers functions to perform calculations in
Computational Commutative Algebra, and some other related areas.  The
library is designed to be pleasant to use while offering good run-time
performance.

%package -n %{libname}
Summary:        C++ library for computations in commutative algebra
Group:          System/Libraries

%description -n %{libname}
The CoCoA C++ library offers functions to perform calculations in
Computational Commutative Algebra, and some other related areas.  The
library is designed to be pleasant to use while offering good run-time
performance.

%package -n %{develname}
Summary:        Headers and library links for %{name}
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Requires:       boost-devel
Requires:       gmp-devel
Requires:       gsl-devel
Requires:       gfan-devel
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{develname}
Headers and library links for developing applications that use %{name}.

%package doc
Summary:        Documentation for %{name}
License:        GFDL
BuildArch:      noarch

%description doc
Documentation for %{name}.

%prep
%autosetup -p0 -n CoCoALib-%{version}

# Use OpenBlas instead of the reference lapack/blas implementation
# sed -i 's,-lblas -llapack,-lopenblas,' configure

# Lots of files incorrectly have executable permissions.  Remove all such
# permissions, then restore the few that are correct.
find -O3 . -type f -perm /0111 \! -name \*.sh -exec chmod a-x {} \+
chmod a+x configure

# Do not suppress compiler command lines
sed -i 's/\$(MAKE) -s/\$(MAKE)/' `find . -name "Makefile"`

# Taken from Fedora rawhide - thanks
sed -e "/ -Wall  -pedantic/d" -i ./configure

%build
export CXXFLAGS+=" -fPIC -I%{_includedir}/frobby -I%{_includedir}/gfanlib  -I%{_includedir}/cddlib"
# This is NOT an autoconf-generated configure script!
./configure --prefix=%{_prefix} --only-cocoalib --threadsafe-hack \
  --with-cxxflags="${CXXFLAGS} %{build_ldflags}" \
  --with-libcddgmp=%{_libdir}/libcddgmp.so \
  --with-libfrobby=%{_libdir}/libfrobby.so \
  --with-libgfan=%{_libdir}/libgfan.so \
  --with-libgsl=%{_libdir}/libgsl.so

%make_build library
%make_build doc

%install
# The Makefile ignores DESTDIR.  Install by hand.

# Install the library
mkdir -p %{buildroot}%{_libdir}
cp -p src/AlgebraicCore/libcocoa.so.0.0.0 %{buildroot}%{_libdir}
ln -s libcocoa.so.0.0.0 %{buildroot}%{_libdir}/libcocoa.so.0
ln -s libcocoa.so.0 %{buildroot}%{_libdir}/libcocoa.so

# Install the headers
mkdir -p %{buildroot}%{_includedir}
cp -a include/CoCoA %{buildroot}%{_includedir}
rm -f %{buildroot}%{_includedir}/{MakeUnifiedHeader.sh,PREPROCESSOR_DEFNS.H-old}

# Remove files from the doc directories that we want to include in %%files
rm -f doc/CoCoALib-tasks/{HTMLTasks,HTMLTasks.C,Makefile,tasks.xml}
rm -f examples/CopyInfo
chmod a-x examples/*.sh

%check
# 32-bit systems are unable to pass some of the tests due to the limited range
# of the FFelem type.  Disable those tests.

#if [ "%{__isa_bits}" = "32" ]; then
#  sed -e '/test-exbugs\.C/d' \
#      -e '/test-DenseUPolyRing1\.C/d' \
#      -e 's/test-IsInteger1\.C //' \
#      -e 's/test-LRSDegeneracy2\.C//' \
#      -e 's/test-MinPoly1\.C//' \
#      -e '/test-module1\.C/d' \
#      -e 's/test-OrderedDomain1\.C//' \
#      -e 's/test-RingElem3\.C//' \
#      -e '/test-RingFp1\.C/d' \
#      -e 's/test-RingZZmodN1\.C//' \
#      -e 's/test-SparsePolyRing1\.C//' \
#      -i src/tests/Makefile
#fi

export LD_LIBRARY_PATH=$PWD/lib
# Don't stop for 32-bit archs.
%make_build check \
%ifarch %{arm} %{ix86}
 || :
%endif


%files -n %{libname}
%license COPYRIGHT-full-text
%doc README
%{_libdir}/libcocoa.so.%{major}{,.*}

%files -n %{develname}
%{_includedir}/CoCoA
%{_libdir}/libcocoa.so

%files doc
%license doc/COPYING
%doc doc/*.html
%doc doc/*.pdf
%doc doc/CoCoALib-tasks
%doc doc/html
%doc examples



%changelog
* Tue Jul 22 2025 aurr <aurr> 0.99850-5.mga10
+ Revision: 2258179
- disable test failure on 32-bit archs
- clean spec file
- rebuild for new gfan lib
+ umeabot <umeabot>
- Mageia 10 Mass Rebuild
+ ns80 <ns80>
- try to fix building with GCC 15

* Mon May 06 2024 daviddavid <daviddavid> 0.99850-1.mga10
+ Revision: 2062542
- new version: 0.99850
- new version: 0.99818
- drop upstreamed patches: noreturn, vector-size
- add cvc5 patch to enable tracing
+ danf <danf>
- Fix URL

* Thu Dec 29 2022 daviddavid <daviddavid> 0.99800-2.mga9
+ Revision: 1927501
- rebuild for new gsl 2.7.1

* Sun Oct 23 2022 ghibo <ghibo> 0.99800-1.mga9
+ Revision: 1898613
- Update to release 0.99800.
- Drop merged or unused patches.
- Update patchset from FC.
- Add gsl-devel to BR.
- Speedup building for x86_64 and aarch64 arch.

* Sat Mar 26 2022 umeabot <umeabot> 0.99712-3.mga9
+ Revision: 1828399
- Mageia 9 Mass Rebuild
+ wally <wally>
- rebuild for boost 1.77.0

* Thu Apr 01 2021 daviddavid <daviddavid> 0.99712-1.mga9
+ Revision: 1712491
- new version: 0.99712

* Fri Sep 25 2020 shlomif <shlomif> 0.99710-1.mga8
+ Revision: 1629980
- New version 0.99710

* Sun Feb 16 2020 umeabot <umeabot> 0.99601-3.mga8
+ Revision: 1529690
- Mageia 8 Mass Rebuild

* Tue Aug 27 2019 daviddavid <daviddavid> 0.99601-2.mga8
+ Revision: 1433759
- rebuild for new gsl 2.6

* Fri Mar 15 2019 shlomif <shlomif> 0.99601-1.mga7
+ Revision: 1377650
- New version - thanks to fedora

* Sun Mar 10 2019 shlomif <shlomif> 0.99600-1.mga7
+ Revision: 1373616
- made the .spec more mageia-like
- import from fedora


* Thu Jan 31 2019 Fedora Release Engineering <releng@fedoraproject.org> - 0.99600-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Sat Oct 13 2018 Jerry James <loganjerry@gmail.com> - 0.99600-2
- Build with openblas instead of atlas (bz 1618942)

* Fri Aug 10 2018 Jerry James <loganjerry@gmail.com> - 0.99600-1
- New upstream version

* Thu Jul 12 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0.99564-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sat Jun 16 2018 Jerry James <loganjerry@gmail.com> - 0.99564-1
- New upstream version
- Drop upstreamed -return patch
- Add -include and -bigrat patches to fix FTBFS

* Mon Jun 11 2018 Jerry James <loganjerry@gmail.com> - 0.99563-2
- Make -doc subpackage noarch

* Sat Jun  9 2018 Jerry James <loganjerry@gmail.com> - 0.99563-1
- Initial RPM
